from distutils.core import setup

setup(
        name = 'lemon123456',
        version = '1.4.0',
        py_modules = ['nester'],
        author = 'xjxu',
        author_email = 'xjxu@thoughtworks.com',
        url = 'http://www.thoughtworks.com',
        description = 'A simple printer of nested lists'
    )
